@@ -1,7 +1,6 @@
 # -*- coding: utf-8 -*-
 from __future__ import absolute_import
 import numpy as np
-from multipledispatch import dispatch
 from pyrr import vector, vector3
 
 class NpProxy(object):
@@ -43,18 +42,26 @@ class BaseObject(np.ndarray):
 class BaseMatrix(BaseObject):
     @classmethod
     def identity(cls, dtype=None):
+        """Creates an identity Matrix.
+        """
         return cls(cls._module.create_identity(dtype), dtype)
 
     @classmethod
     def from_eulers(cls, eulers, dtype=None):
+        """Creates a Matrix from the specified Euler angles.
+        """
         return cls(cls._module.create_from_eulers(eulers, dtype=dtype))
 
     @classmethod
     def from_quaternion(cls, quat, dtype=None):
+        """Creates a Matrix from a Quaternion.
+        """
         return cls(cls._module.create_from_quaternion(quat, dtype=dtype))
 
     @classmethod
     def from_inverse_of_quaternion(cls, quat, dtype=None):
+        """Creates a Matrix from the inverse of the specified Quaternion.
+        """
         return cls(cls._module.create_from_inverse_of_quaternion(quat, dtype=dtype))
 
     @classmethod
@@ -63,6 +70,8 @@ class BaseMatrix(BaseObject):
 
     @classmethod
     def from_x_rotation(cls, theta, dtype=None):
+        """Creates a Matrix with a rotation around the X-axis.
+        """
         return cls(cls._module.create_from_x_rotation(theta, dtype=dtype))
 
     @classmethod
@@ -71,19 +80,27 @@ class BaseMatrix(BaseObject):
 
     @classmethod
     def from_z_rotation(cls, theta, dtype=None):
+        """Creates a Matrix with a rotation around the Z-axis.
+        """
         return cls(cls._module.create_from_z_rotation(theta, dtype=dtype))
 
     @property
     def inverse(self):
-        return self._module.inverse(self)
+        """Returns the inverse of this matrix.
+        """
+        return type(self)(self._module.inverse(self))
 
 class BaseVector(BaseObject):
+    @classmethod
+    def from_matrix44_translation(cls, matrix, dtype=None):
+        return cls(cls._module.create_from_matrix44_translation(matrix, dtype))
+
     def normalise(self):
         self[:] = self.normalised
 
     @property
     def normalised(self):
-        return self.__class__(self._module.normalise(self))
+        return type(self)(self._module.normalise(self))
 
     @property
     def squared_length(self):
@@ -98,16 +115,16 @@ class BaseVector(BaseObject):
         self[:] = vector.set_length(self, length)
 
     def dot(self, other):
-        return vector.dot(self, self.__class__(other))
+        return vector.dot(self, type(self)(other))
 
     def cross(self, other):
-        return self.__class__(vector3.cross(self[:3], other[:3]))
+        return type(self)(vector3.cross(self[:3], other[:3]))
 
     def interpolate(self, other, delta):
-        return self.__class__(vector.interpolate(self, self.__class__(other), delta))
+        return type(self)(vector.interpolate(self, type(self)(other), delta))
 
     def normal(self, v2, v3, normalise_result=True):
-        return self.__class__(vector3.generate_normals(self, self.__class__(v2), self.__class__(v3), normalise_result))
+        return type(self)(vector3.generate_normals(self, type(self)(v2), type(self)(v3), normalise_result))
 
 class BaseQuaternion(BaseObject):
     pass
