@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """Provides functions for creating and manipulating 4D vectors.
 """
-from __future__ import absolute_import, division, print_function, unicode_literals
+from __future__ import absolute_import, division, print_function
 import numpy as np
 from .utils import parameters_as_numpy_arrays
 
